`timescale 1ps / 1ps
//*****************************************************************************
// File Name            : stepper_motor_ap.v
//-----------------------------------------------------------------------------
// Function             : unipolar stepper motor controller
//                        
//-----------------------------------------------------------------------------
// Designer             : yokomizo 
//-----------------------------------------------------------------------------
// History
// -.-- 2014/9/02@a
//*****************************************************************************

module stepper_motor_ap (
  clk,
  reset,
  uart_txd,uart_rxd,
  busy_0,m_a_0,m_a_b_0,m_b_0,m_b_b_0,
  busy_1,m_a_1,m_a_b_1,m_b_1,m_b_b_1,
  busy_2,m_a_2,m_a_b_2,m_b_2,m_b_b_2,
  busy_3,m_a_3,m_a_b_3,m_b_3,m_b_b_3
);

  input clk;
  input reset;
  output uart_txd;
  input uart_rxd;
  output busy_0,m_a_0,m_a_b_0,m_b_0,m_b_b_0;
  output busy_1,m_a_1,m_a_b_1,m_b_1,m_b_b_1;
  output busy_2,m_a_2,m_a_b_2,m_b_2,m_b_b_2;
  output busy_3,m_a_3,m_a_b_3,m_b_3,m_b_b_3;
  
  wire [31:0] gpo_1;
  wire [31:0] gpo_2;
  wire [7:0] gpo_3;
  wire [7:0] gpi_1;
  wire GPI1_Interrupt;  
  wire clk_100m;  
  wire clk_50m;  
  wire locked;  
  wire reset_unlock;  
  wire rstb;
 //NbN
  clk_gen clknetwork
   (// Clock in ports
    .CLK_IN1            (clk),
    // Clock out ports
    .CLK_OUT1           (clk_100m),
    .CLK_OUT2           (clk_50m),
    // Status and control signals
    .RESET              (reset),
    .LOCKED             (locked));
	
	assign reset_unlock =((reset==1'b1)||(locked==1'b0))?1'b1:1'b10;
	assign rstb = ~reset_unlock;
   //vZbT 
   /*
   nios2_e nios2_e(
		.clk_clk(clk),        //   clk.clk
		.reset_reset_n(rstb), // reset.reset_n
		.uart_rxd(uart_rxd),  //  uart.rxd
		.uart_txd(uart_txd),  //      .txd
	    .gpo_1_export(gpo_1), // gpo_1.export
		.gpo_2_export(gpo_2), // gpo_2.export
		.gpo_3_export(gpo_3), // gpo_3.export
		.gpi_1_export(gpi_1)  // gpi_1.export
	);
	*/
mb_mcs mcs_0 (
  .Clk(clk_50m), // input Clk
  .Reset(reset_unlock), // input Reset
  .UART_Rx(uart_rxd), // input UART_Rx
  .UART_Tx(uart_txd), // output UART_Tx
  .GPO1(gpo_1), // output [31 : 0] GPO1
  .GPO2(gpo_2), // output [31 : 0] GPO2
  .GPO3(gpo_3), // output [7 : 0] GPO3
  .GPI1(gpi_1), // input [7 : 0] GPI1
  .GPI1_Interrupt(GPI1_Interrupt) // output GPI1_Interrupt
);
	assign gpi_1 ={4'b0000,busy_3,busy_2,busy_1,busy_0};	
	
   //[^H_0
	stepper_motor_uni m_0 (
		.clk(clk_50m), 
		.rstb(rstb), 
		.start(gpo_3[0]),  
		.en(gpo_1[0]), 
		.cw(gpo_1[1]),  
		.step_t(gpo_1[7:4]),  
		.step_n(gpo_1[15:8]),  
		.busy(busy_0),
		.m_a(m_a_0),
		.m_a_b(m_a_b_0),
		.m_b(m_b_0),
		.m_b_b(m_b_b_0)
	);
   //[^H_1	
	stepper_motor_uni m_1 (
		.clk(clk_50m), 
		.rstb(rstb), 
		.start(gpo_3[1]),  
		.en(gpo_1[16]), 
		.cw(gpo_1[17]),  
		.step_t(gpo_1[23:20]),  
		.step_n(gpo_1[31:24]),  
		.busy(busy_1),
		.m_a(m_a_1),
		.m_a_b(m_a_b_1),
		.m_b(m_b_1),
		.m_b_b(m_b_b_1)
	);
   //[^H_2	
	stepper_motor_uni m_2 (
		.clk(clk_50m), 
		.rstb(rstb), 
		.start(gpo_3[2]),  
		.en(gpo_2[0]), 
		.cw(gpo_2[1]),  
		.step_t(gpo_2[7:4]),  
		.step_n(gpo_2[15:8]),  
		.busy(busy_2),
		.m_a(m_a_2),
		.m_a_b(m_a_b_2),
		.m_b(m_b_2),
		.m_b_b(m_b_b_2)
	);
   //[^H_3	
	stepper_motor_uni m_3 (
		.clk(clk_50m), 
		.rstb(rstb), 
		.start(gpo_3[3]),  
		.en(gpo_2[16]), 
		.cw(gpo_2[17]),  
		.step_t(gpo_2[23:20]),  
		.step_n(gpo_2[31:24]),  
		.busy(busy_3),
		.m_a(m_a_3),
		.m_a_b(m_a_b_3),
		.m_b(m_b_3),
		.m_b_b(m_b_b_3)
	);
endmodule






